package CPAN::Search::Lite;
use strict;
use warnings;

our $VERSION = 0.77;

1;

__END__

=head1 NAME

CPAN::Search::Lite - setup and maintain a searchable CPAN database

=head1 SEE ALSO

L<CPAN::Search::Lite::Index>, for setting up and maintaining
the database, L<CPAN::Search::Lite::Query> for an
interface to querying the database, and
L<Apache2::CPAN::Query> for a mod_perl 2 handler to
C<CPAN::Search::Lite::Query>.
Development takes place on the CPAN-Search-Lite project
at L<http://sourceforge.net/projects/cpan-search/>.

=head1 COPYRIGHT

This software is copyright 2004 by Randy Kobes
E<lt>randy@theoryx5.uwinnipeg.caE<gt>. Use and
redistribution are under the same terms as Perl itself.

=head1 CURRENT MAINTAINER

Kenichi Ishigaki E<lt>ishigaki@cpan.orgE<gt>

=cut
